coherence.upnp.services.clients.wan_ip_connection_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.services.clients.wan_ip_connection_client (module)

class `WANIPConnectionClient`(service)

  Bases: `object`

  `remove`()
  `subscribe_for_variable`(var_name, callback, signal=False)
  `get_external_ip_address`()
  `get_all_port_mapping_entries`()
  `get_generic_port_mapping_entry`(port_mapping_index)
  `get_specific_port_mapping_entry`(remote_host='', external_port=0, protocol='TCP')
  `add_port_mapping`(remote_host='', external_port=0, protocol='TCP', internal_port=None, internal_client=None, enabled=False, port_mapping_description='', lease_duration=60)
  `delete_port_mapping`(remote_host='', external_port=0, protocol='TCP')